:py:mod:`piel.sax.utils`
========================

.. py:module:: piel.sax.utils

.. autoapi-nested-parse::

   This file provides a set of utilities that allow much easier integration between `sax` and the tools that we use.



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.sax.utils.get_common_netlist_instance_keys



.. py:function:: get_common_netlist_instance_keys() -> list

   Get the common netlist instance keys for a given netlist.

   :returns: List of common netlist instance keys.
   :rtype: list
